package com.example.mathseduc.ui

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.mathseduc.controllers.ControllerLobby
import com.example.mathseduc.controllers.ControllerQuestion
import com.example.mathseduc.ui.theme.Colors
import kotlinx.coroutines.channels.ticker


@Composable
fun QuizMultiScreen(lobbyId: Int) {
    var progressBar1Value by remember { mutableStateOf(0.0f) }
    var chronoValue by remember { mutableStateOf(0.0f) }
    var listQuestion by remember { mutableStateOf(ControllerQuestion.getQuestionsForLobby(ControllerLobby.getIdQuestionsLobby(lobbyId))) }

    LaunchedEffect(Unit) {
        val timer = ticker(delayMillis = 100) // Update every 100 milliseconds
        for (tick in timer) {
            progressBar1Value += 0.1f // Increment ProgressBar1 value every 100ms
            chronoValue += 0.1f // Increment Chrono value every 100ms
            if (chronoValue >= 30f) {
                // Time's up, do something
                break
            }
        }
    }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {

        // ProgressBar1
        CustomProgressBar(progressBar1Value)

        // Chrono ProgressBar
        ChronoProgressBar(chronoValue)

        Row(
            modifier = Modifier
                .weight(2f)
                .padding(vertical = 20.dp)
        ) {
            Spacer(modifier = Modifier.weight(1f))

            Box(
                modifier = Modifier
                    .weight(5f)
                    .background(color = Colors.Grey, shape = RoundedCornerShape(8.dp))
            ) {
                Text(
                    text = "test",
                    modifier = Modifier
                        .padding(16.dp),
                    color = Colors.White,
                    fontSize = 20.sp,
                    textAlign = TextAlign.Center
                )
            }

            Spacer(modifier = Modifier.weight(1f))
        }

        Column(modifier = Modifier.weight(1f)) {
            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(bottom = 10.dp)
            ) {
                Spacer(modifier = Modifier.weight(0.25f))

                Button(
                    onClick = { /* Handle button click */ },
                    modifier = Modifier
                        .weight(2f),
                    shape = RoundedCornerShape(15),
                    colors = ButtonDefaults.buttonColors(Colors.Blue),

                    ) {
                    Text(text = "Answer1")
                }

                Spacer(modifier = Modifier.weight(0.5f))

                Button(
                    onClick = { /* Handle button click */ },
                    modifier = Modifier
                        .weight(2f),
                    shape = RoundedCornerShape(15),
                    colors = ButtonDefaults.buttonColors(Colors.Green),
                ) {
                    Text(text = "Answer2")
                }

                Spacer(modifier = Modifier.weight(0.25f))
            }

            Row(
                modifier = Modifier
                    .fillMaxWidth()
            ) {
                Spacer(modifier = Modifier.weight(0.25f))

                Button(
                    onClick = { /* Handle button click */ },
                    modifier = Modifier
                        .weight(2f),
                    shape = RoundedCornerShape(15),
                    colors = ButtonDefaults.buttonColors(Colors.Orange),
                ) {
                    Text(text = "Answer3")
                }

                Spacer(modifier = Modifier.weight(0.5f))

                Button(
                    onClick = { /* Handle button click */ },
                    modifier = Modifier
                        .weight(2f),
                    shape = RoundedCornerShape(15),
                    colors = ButtonDefaults.buttonColors(Colors.Purple500),
                ) {
                    Text(text = "Answer4")
                }

                Spacer(modifier = Modifier.weight(0.25f))
            }
        }

        Row(
            modifier = Modifier
                .fillMaxWidth()
                .weight(1f)
                .padding(vertical = 10.dp)
        ) {
            Spacer(modifier = Modifier.weight(1f))

            Button(
                onClick = { /* Handle button click (Passer) */ },
                modifier = Modifier
                    .weight(2f),
                shape = RoundedCornerShape(15),
                colors = ButtonDefaults.buttonColors(Colors.Red),
            ) {
                Text(text = "Passer")
            }

            Spacer(modifier = Modifier.weight(0.15f))

            Button(
                onClick = {
                    progressBar1Value += 3f
                },
                modifier = Modifier
                    .weight(2f),
                shape = RoundedCornerShape(15),
                colors = ButtonDefaults.buttonColors(Colors.Green),
            ) {
                Text(text = "Valider")
            }

            Spacer(modifier = Modifier.weight(1f))
        }
    }
}

@Composable
fun CustomProgressBar(progressBarValue: Float) {
    LinearProgressIndicator(
        progress = progressBarValue / 100f,
        modifier = Modifier.fillMaxWidth()
    )
}

@Composable
fun ChronoProgressBar(chronoValue: Float) {
    CircularProgressIndicator(
        progress = chronoValue / 30f,
        modifier = Modifier.padding(horizontal = 10.dp)
    )
}
